@@ -31,12 +31,12 @@ def retry(attempts, func, *args, **kwargs):
 
 class OSSNodeStorage(NodeStorage):
 
-    def __init__(self, bucket_name=None, endpoint=None, oss_access_key_id=None, oss_secret_access_key=None, max_retries=3):
+    def __init__(self, bucket_name=None, prefix=None, endpoint=None, oss_access_key_id=None, oss_secret_access_key=None, max_retries=3):
         # self.max_retries = max_retries
         # self.bucket_name = bucket_name
         # self.client = boto3.client(
         #     's3', endpoint_url=endpoint, aws_access_key_id=aws_access_key_id, aws_secret_access_key=aws_secret_access_key)
-        self.prefix = "nodedatas/"
+        self.prefix = '' if not prefix else prefix     # 不要prefix的时候oss的读取性能是最好的
         self.max_retries = max_retries
         self.bucket_name = bucket_name
         # 阿里云主账号AccessKey拥有所有API的访问权限，风险很高。强烈建议您创建并使用RAM账号进行API访问或日常运维，请登录RAM控制台创建RAM账号。
